"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const optionalDeps = {
    'cra': {
        "react": "^17.0.2",
        "react-dom": "^17.0.2",
        "react-scripts": "5.0.0",
        "web-vitals": "^2.1.2",
        "react-manage-providers": "^0.0.6",
    },
    'mui:true': {
        "@emotion/react": "^11.7.1",
        "@emotion/styled": "^11.6.0",
        "@mui/material": "^5.4.0"
    },
    'gql:true': {
        "type-graphql": "^1.1.1",
        "reflect-metadata": "^0.1.13",
        "@apollo/client": "^3.5.10",
        "graphql.macro": "^1.4.2"
    },
    'express:true': {
        "express": "^4.17.2"
    },
    'express:false,gql:true': {
        "apollo-server": "^3.6.3"
    },
    'express:true,gql:true': {
        "apollo-server-express": "^3.6.2",
        "apollo-server-core": "^3.6.2"
    },
    'auth:jwt': {
        "jsonwebtoken": "^8.5.1"
    },
    'auth:firebase': {
        "firebase-admin": "^10.0.2"
    },
    'mongodb:true': {
        "mongodb": "^3.7.3"
    },
    'router:true': {
        "react-router-dom": "^5.2.1",
    },
    'i18n:true': {
        "i18next": "^21.6.12",
        "i18next-browser-languagedetector": "^6.1.3",
        "i18next-resources-to-backend": "^1.0.0",
        "react-i18next": "^11.15.5"
    },
    'jotai:true': {
        "jotai": "^1.6.0"
    }
};
const optionalDevDeps = {
    'cra': {
        "@testing-library/jest-dom": "^5.16.1",
        "@testing-library/react": "^12.1.2",
        "@testing-library/user-event": "^13.5.0",
        "@types/jest": "^27.0.3",
        "@types/node": "^16.11.17",
        "@types/react": "^17.0.38",
        "@types/react-dom": "^17.0.11",
        "typescript": "^4.5.4",
        "concurrently": "^7.0.0",
        "ts-node-dev": "^1.1.8",
        "cross-env": "^7.0.3"
    },
    'gql:true': {
        "@graphql-codegen/cli": "^2.6.2",
        "@graphql-codegen/fragment-matcher": "^3.2.1",
        "@graphql-codegen/typescript": "^2.4.5",
        "@graphql-codegen/typescript-operations": "^2.3.2",
        "@graphql-codegen/typescript-react-apollo": "^3.2.8",
        "@graphql-tools/load": "^7.5.2",
        "@graphql-tools/url-loader": "^7.8.0",
        "generate-graphql-operations": "^0.0.5",
        "graphql-tools": "^8.2.0"
    },
    'express:true': {
        "@types/express": "^4.17.13"
    },
    'auth:jwt': {
        "@types/jsonwebtoken": "^8.5.8"
    },
    'router:true': {
        "@types/react-router-dom": "^5.2.1",
    }
};
function generatePackageJson(_a) {
    var { name, port } = _a, options = __rest(_a, ["name", "port"]);
    return __awaiter(this, void 0, void 0, function* () {
        const dependencies = substractOptionalDeps(optionalDeps, options);
        const devDependencies = substractOptionalDeps(optionalDevDeps, options);
        return {
            "name": name,
            "version": "0.1.0",
            "private": true,
            "scripts": Object.assign(Object.assign({ "start": `concurrently -n server,app \"npm run start:server\" \"npm run start:app\"`, "start:app": "react-scripts start", "start:server": `cross-env PORT=${port} ts-node-dev --project ./tsconfig-server.json ./src/server.ts` }, options.gql ? {
                "gql:codegen": "graphql-codegen",
                "gql:operations": `generate-gql-ops --url http://localhost:${port}/api --path ./src/graphql`,
                "gql": "npm run gql:operations && npm run gql:codegen"
            } : {}), { "build": "react-scripts build", "test": "react-scripts test", "eject": "react-scripts eject" }),
            "eslintConfig": {
                "extends": [
                    "react-app",
                    "react-app/jest"
                ]
            },
            "browserslist": {
                "production": [
                    ">0.2%",
                    "not dead",
                    "not op_mini all"
                ],
                "development": [
                    "last 1 chrome version",
                    "last 1 firefox version",
                    "last 1 safari version"
                ]
            },
            dependencies,
            devDependencies
        };
    });
}
exports.default = generatePackageJson;
function substractOptionalDeps(deps, filters) {
    const keys = Object.keys(deps).filter(rules => (0, _1.filterRules)(rules, filters));
    return Object.assign({}, ...keys.map(k => deps[k]));
}
//# sourceMappingURL=generatePackageJson.js.map